@@ -253,6 +253,8 @@ class TileLayer(RasterLayer):
     def on_load(self, callback, remove=False):
         self._load_callbacks.register_callback(callback, remove=remove)
 
+    def redraw(self):
+        self.send({'msg':'redraw'})
 
 class LocalTileLayer(TileLayer):
     _view_name = Unicode('LeafletLocalTileLayerView').tag(sync=True)
@@ -512,7 +514,7 @@ class GeoData(GeoJSON):
     geo_dataframe = Instance('geopandas.GeoDataFrame')
 
     def __init__(self, **kwargs):
-        super(GeoJSON, self).__init__(**kwargs)
+        super(GeoData, self).__init__(**kwargs)
         self.data = self._get_data()
 
     @observe('geo_dataframe')
@@ -776,6 +778,23 @@ class DrawControl(Control):
         self.send({'msg': 'clear_markers'})
 
 
+class ZoomControl(Control):
+    _view_name = Unicode('LeafletZoomControlView').tag(sync=True)
+    _model_name = Unicode('LeafletZoomControlModel').tag(sync=True)
+
+    zoom_in_text = Unicode('+').tag(sync=True, o=True)
+    zoom_in_title = Unicode('Zoom in').tag(sync=True, o=True)
+    zoom_out_text = Unicode('-').tag(sync=True, o=True)
+    zoom_out_title = Unicode('Zoom out').tag(sync=True, o=True)
+
+
+class AttributionControl(Control):
+    _view_name = Unicode('LeafletAttributionControlView').tag(sync=True)
+    _model_name = Unicode('LeafletAttributionControlModel').tag(sync=True)
+
+    prefix = Unicode('Leaflet').tag(sync=True, o=True)
+
+
 class MapStyle(Style, Widget):
     """ Map Style Widget """
     _model_name = Unicode('LeafletMapStyleModel').tag(sync=True)
@@ -830,8 +849,6 @@ class Map(DOMWidget, InteractMixin):
     inertia_deceleration = Int(3000).tag(sync=True, o=True)
     inertia_max_speed = Int(1500).tag(sync=True, o=True)
     # inertia_threshold = Int(?, o=True).tag(sync=True)
-    zoom_control = Bool(True).tag(sync=True, o=True)
-    attribution_control = Bool(True).tag(sync=True, o=True)
     # fade_animation = Bool(?).tag(sync=True, o=True)
     # zoom_animation = Bool(?).tag(sync=True, o=True)
     zoom_animation_threshold = Int(4).tag(sync=True, o=True)
@@ -844,6 +861,12 @@ class Map(DOMWidget, InteractMixin):
     default_style = InstanceDict(MapStyle).tag(sync=True, **widget_serialization)
     dragging_style = InstanceDict(MapStyle).tag(sync=True, **widget_serialization)
 
+    zoom_control = Bool(True)
+    zoom_control_instance = ZoomControl()
+
+    attribution_control = Bool(True)
+    attribution_control_instance = AttributionControl(position='bottomright')
+
     @default('dragging_style')
     def _default_dragging_style(self):
         return {'cursor': 'move'}
@@ -880,6 +903,28 @@ class Map(DOMWidget, InteractMixin):
         self.on_displayed(self._fire_children_displayed)
         self.on_msg(self._handle_leaflet_event)
 
+        if self.zoom_control:
+            self.add_control(self.zoom_control_instance)
+
+        if self.attribution_control:
+            self.add_control(self.attribution_control_instance)
+
+    @observe('zoom_control')
+    def observe_zoom_control(self, change):
+        if change['new']:
+            self.add_control(self.zoom_control_instance)
+        else:
+            if self.zoom_control_instance in self.controls:
+                self.remove_control(self.zoom_control_instance)
+
+    @observe('attribution_control')
+    def observe_attribution_control(self, change):
+        if change['new']:
+            self.add_control(self.attribution_control_instance)
+        else:
+            if self.attribution_control_instance in self.controls:
+                self.remove_control(self.attribution_control_instance)
+
     def _fire_children_displayed(self, widget, **kwargs):
         for layer in self.layers:
             layer._handle_displayed(**kwargs)
